pub struct PerfProfiler { /* private fields */ }Expand description
Profiles performance of the protocol
Implements Tracer trait so it can be embedded into protocol execution. PerfProfiler keeps track of time
passed between each step of protocol. After protocol is completed, you can obtain a PerfReport via
.get_report() method that contains all the measurements.
Implementations
Sourceimpl PerfProfiler
impl PerfProfiler
Sourcepub fn new() -> Self
pub fn new() -> Self
Constructs new PerfProfiler
Sourcepub fn get_report(&self) -> Result<PerfReport, ProfileError>
pub fn get_report(&self) -> Result<PerfReport, ProfileError>
Obtains a report
Returns error if protocol behaved unexpectedly