pub struct PerfReport {
pub setup: Duration,
pub setup_stages: Vec<StageDuration>,
pub rounds: Vec<RoundDuration>,
/* private fields */
}Expand description
Performance report generated by PerfProfiler
Fields
setup: DurationDuration of setup phase (time after protocol began and before first round started)
setup_stages: Vec<StageDuration>Stages of setup phase
rounds: Vec<RoundDuration>Performance report for each round
Implementations
Sourceimpl PerfReport
impl PerfReport
Sourcepub fn display_io(self, display: bool) -> Self
pub fn display_io(self, display: bool) -> Self
Specifies whether time spent on i/o should be rendered in the final report
Time spent on i/o is the time when signer was sending messages or waiting other parties to send messages